
Compiling code ahead of time
============================

.. _pycc:

.. todo:: The API for ahead of time compilation isn't stabilized.
   Adventurous users can still try the ``pycc`` utility which is installed
   as part of Numba.


